@@ -1,4 +1,4 @@
-from .test import *
+from .base import *
 
 INSTALLED_APPS += (
     'django_extensions',
@@ -10,11 +10,10 @@ else:
     INSTALLED_APPS += 'debug_toolbar.apps.DebugToolbarConfig'
 
 DATABASES['default']['NAME'] = 'db.sqlite3'
-STATIC_URL = '/static/'
 MIDDLEWARE_CLASSES += (
     'debug_toolbar.middleware.DebugToolbarMiddleware',
     # Allow to use debug toolbar with json response
-    'tests.testapp.middleware.NonHtmlDebugToolbarMiddleware',
+    # 'tests.testapp.middleware.NonHtmlDebugToolbarMiddleware',
 )
 INTERNAL_IPS = [
     '127.0.0.1',
